@@ -334,9 +334,10 @@ class DataPlotterCallback(Callback):
         self.batch_logs_max = 0
         self.inputs_outputs_real = []
         self.previous_batch = 0
-        for sample_index in range(self.data_set_sample_count):
-            if self.shuffle:
-                sample_index = random.randint(0, len(self.data_set) - 1)
+        
+        sample_indices = list(random.sample(range(0, len(self.data_set)-1), self.data_set_sample_count)) if self.shuffle else list(range(0, self.data_set_sample_count))
+        
+        for sample_index in sample_indices:
             input_real, output_real = self.data_set.__getitem__(sample_index)
             self.inputs_outputs_real.append((input_real, output_real))
     
@@ -457,7 +458,7 @@ class DataPlotterCallback(Callback):
             plt.grid(True)
             plt.tight_layout()
             plt.xlabel('Epoch')
-            plt.yscale('log')
+            #plt.yscale('log')
 
         plt.savefig(os.path.join(output_directory_path, "{}.png".format(title)))
         plt.clf()
