@@ -34,9 +34,9 @@ class VanillaGanNnTrainer(AbstractNnTrainer):
         generator_neural_network: torch.nn.Module, 
         discriminator_neural_network: torch.nn.Module, 
         generator_optimizer_fn: Any = torch.optim.Adam,
-        generator_optimizer_params: Dict = dict(lr=0.0001),
+        generator_optimizer_params: Dict = dict(lr=0.0001, betas=(0.5, 0.9)),
         discriminator_optimizer_fn: Any = torch.optim.Adam,
-        discriminator_optimizer_params: Dict = dict(lr=0.0001),
+        discriminator_optimizer_params: Dict = dict(lr=0.0001, betas=(0.5, 0.9)),
         scheduler_fn: Any = None,
         scheduler_params: Dict = field(default_factory=dict),
         dtype: Any = torch.float32,
