@@ -7,18 +7,6 @@ import numpy as np
 
 from scipy import interpolate
 
-def init_console_logger(logger, verbose=False):
-    stream_handler = logging.StreamHandler()
-    if verbose:
-        stream_handler.setLevel(logging.DEBUG)
-    else:
-        stream_handler.setLevel(logging.INFO)
-    formatter = logging.Formatter('[%(levelname)s] %(message)s')
-    stream_handler.setFormatter(formatter)
-    file_handler = logging.FileHandler("model.log")
-    logger.addHandler(stream_handler)
-    logger.addHandler(file_handler)
-
 # Training
 EPOCHS = 150
 BATCH_SIZE = 128
@@ -28,13 +16,6 @@ SAMPLE_NUM = 10  # Generate 10 samples every sample generation.
 
 OUTPUT_PATH = os.path.join(os.getcwd(), "output")
 
-# =============Logger===============
-LOGGER = logging.getLogger('nn_logger')
-LOGGER.setLevel(logging.DEBUG)
-
-LOGGER.info('Initialized logger.')
-init_console_logger(LOGGER)
-
 def make_path(output_path):
     if not os.path.isdir(output_path):
         os.makedirs(output_path)
